@@ -84,16 +84,6 @@ extern const char *str_tls_level(int);
 #define ssl_cipher_stack_t STACK_OF(SSL_CIPHER)
 #define ssl_comp_stack_t STACK_OF(SSL_COMP)
 
- /*-
-  * Official way to check minimum OpenSSL API version from 3.0 onward.
-  * We simply define it false for all prior versions, where we typically also
-  * need the patch level to determine API compatibility.
-  */
-#ifndef OPENSSL_VERSION_PREREQ
-#define OPENSSL_VERSION_PREREQ(m,n) 0
-#endif
-
-
 #if (OPENSSL_VERSION_NUMBER < 0x1000200fUL)
 #error "OpenSSL releases prior to 1.0.2 are no longer supported"
 #endif
@@ -119,8 +109,6 @@ extern const char *str_tls_level(int);
 #define TLS_method SSLv23_method
 #define TLS_client_method SSLv23_client_method
 #define TLS_server_method SSLv23_server_method
-#define EVP_MD_CTX_new EVP_MD_CTX_create
-#define EVP_MD_CTX_free EVP_MD_CTX_destroy
 #endif
 
  /* Backwards compatibility with OpenSSL < 1.1.1 */
@@ -259,7 +247,6 @@ typedef struct {
     /* Public, read-only. */
     char   *peer_CN;			/* Peer Common Name */
     char   *issuer_CN;			/* Issuer Common Name */
-    char   *peer_sni;			/* SNI sent to or by the peer */
     char   *peer_cert_fprint;		/* ASCII certificate fingerprint */
     char   *peer_pkey_fprint;		/* ASCII public key fingerprint */
     int     peer_status;		/* Certificate and match status */
@@ -350,6 +337,10 @@ struct TLS_APPL_STATE {
     SSL_CTX *sni_ctx;
     int     log_mask;
     char   *cache_type;
+    char   *cipher_exclusions;		/* Last cipher selection state */
+    char   *cipher_list;		/* Last cipher selection state */
+    int     cipher_grade;		/* Last cipher selection state */
+    VSTRING *why;
 };
 
  /*
@@ -427,13 +418,6 @@ extern void tls_param_init(void);
 #define SSL_OP_NO_TLSv1_3	0L	/* Noop */
 #endif
 
-/*
- * Always used when defined, SMTP has no truncation attacks.
- */
-#ifndef SSL_OP_IGNORE_UNEXPECTED_EOF
-#define SSL_OP_IGNORE_UNEXPECTED_EOF    0L
-#endif
-
 #define TLS_KNOWN_PROTOCOLS \
 	( TLS_PROTOCOL_SSLv2 | TLS_PROTOCOL_SSLv3 | TLS_PROTOCOL_TLSv1 \
 	   | TLS_PROTOCOL_TLSv1_1 | TLS_PROTOCOL_TLSv1_2 | TLS_PROTOCOL_TLSv1_3 )
@@ -450,8 +434,7 @@ extern void tls_param_init(void);
  * just exposed via hex codes or named elements of tls_ssl_options.
  */
 #define TLS_SSL_OP_MANAGED_BITS \
-	(SSL_OP_CIPHER_SERVER_PREFERENCE | SSL_OP_IGNORE_UNEXPECTED_EOF | \
-	 TLS_SSL_OP_PROTOMASK(~0))
+	(SSL_OP_CIPHER_SERVER_PREFERENCE | TLS_SSL_OP_PROTOMASK(~0))
 
 extern int tls_protocol_mask(const char *);
 
@@ -475,8 +458,8 @@ extern const NAME_CODE tls_cipher_grade_table[];
  /*
   * Cipher lists with exclusions.
   */
-extern const char *tls_set_ciphers(TLS_SESS_STATE *, const char *,
-				           const char *);
+extern const char *tls_set_ciphers(TLS_APPL_STATE *, const char *,
+				           const char *, const char *);
 
  /*
   * Populate TLS context with TLS 1.3-related signature parameters.
@@ -699,7 +682,6 @@ extern void tls_dane_set_callback(SSL_CTX *, TLS_SESS_STATE *);
  /*
   * tls_fprint.c
   */
-extern const EVP_MD *tls_digest_byname(const char *, EVP_MD_CTX **);
 extern char *tls_digest_encode(const unsigned char *, int);
 extern char *tls_data_fprint(const char *, int, const char *);
 extern char *tls_cert_fprint(X509 *, const char *);
